@@ -1,7 +1,7 @@
 //
 // Query.cs
 //
-// Copyright (C) 2004-2005 Novell, Inc.
+// Copyright (C) 2004-2007 Novell, Inc.
 //
 
 //
@@ -27,8 +27,9 @@
 
 using System;
 using System.IO;
-using System.Collections;
 using System.Text;
+using System.Collections;
+using System.Collections.Generic;
 using System.Xml.Serialization;
 
 using Beagle.Util;
@@ -45,24 +46,14 @@ namespace Beagle {
 
 	public class Query : RequestMessage {
 
-		// FIXME: This is a good default when on an airplane.
-		private Beagle.QueryDomain domainFlags = QueryDomain.Local | QueryDomain.System; 
-
 		private ArrayList parts = new ArrayList ();
-		private ArrayList mimeTypes = new ArrayList ();
-		private ArrayList hitTypes = new ArrayList ();
-		private ArrayList searchSources = new ArrayList ();
 
 		private ArrayList exact_text = null;
 		private ArrayList stemmed_text = null;
 
-		private QueryPart_Or mime_type_part = null;
-		private QueryPart_Or hit_type_part = null;
-		private QueryPart_Or source_part = null;
+		// FIXME: This is a good default when on an airplane.
+		private QueryDomain domain_flags = QueryDomain.Local | QueryDomain.System;
 
-		private bool is_index_listener = false;
-
-		// Events to make things nicer to clients
 		public delegate void HitsAdded (HitsAddedResponse response);
 		public event HitsAdded HitsAddedEvent;
 
@@ -107,7 +98,7 @@ namespace Beagle {
 		private void OnFinished (ResponseMessage r)
 		{
 			FinishedResponse response = (FinishedResponse) r;
-
+	
 			if (this.FinishedEvent != null)
 				this.FinishedEvent (response);
 		}
@@ -115,7 +106,6 @@ namespace Beagle {
 		private void OnError (ResponseMessage r)
 		{
 			ErrorResponse response = (ErrorResponse) r;
-
 			throw new ResponseMessageException (response);
 		}
 
@@ -141,6 +131,7 @@ namespace Beagle {
 		// that they will work for you!  Listener queries should only be
 		// used for debugging and testing.
 
+		private bool is_index_listener = false;
 		public bool IsIndexListener {
 			set { is_index_listener = value; }
 			get { return is_index_listener; }
@@ -164,8 +155,7 @@ namespace Beagle {
 		// the daemon.
 		public void AddText (string str)
 		{
-			QueryPart_Human part;
-			part = new QueryPart_Human ();
+			QueryPart_Human part = new QueryPart_Human ();
 			part.QueryString = str;
 			AddPart (part);
 		}
@@ -209,162 +199,24 @@ namespace Beagle {
 						
 		///////////////////////////////////////////////////////////////
 
-		// This API is DEPRECATED.
-		// The mime type is now stored in the beagle:MimeType property.
-		// To restrict on mime type, just do a normal property query.
-
-		public void AddMimeType (string str)
+		public void AddDomain (QueryDomain domain)
 		{
-			mimeTypes.Add (str);
-
-			if (mime_type_part == null) {
-				mime_type_part = new QueryPart_Or ();
-				AddPart (mime_type_part);
-			}
-
-			// Create a part for this mime type.
-			QueryPart_Property part;
-			part = new QueryPart_Property ();
-			part.Type = PropertyType.Keyword;
-			part.Key = "beagle:MimeType";
-			part.Value = str;
-			mime_type_part.Add (part);
+			domain_flags |= domain;
 		}
 
-		public bool AllowsMimeType (string str)
+		public void RemoveDomain (QueryDomain domain)
 		{
-			if (mimeTypes.Count == 0)
-				return true;
-			foreach (string mt in mimeTypes)
-				if (str == mt)
-					return true;
-			return false;
+			domain_flags &= ~domain;
 		}
 
-		[XmlArrayItem (ElementName="MimeType",
-			       Type=typeof (string))]
-		[XmlArray (ElementName="MimeTypes")]
-		public ArrayList MimeTypes {
-			get { return mimeTypes; }
-		}
-
-		public bool HasMimeTypes {
-			get { return mimeTypes.Count > 0; }
-		}
-
-		///////////////////////////////////////////////////////////////
-
-		// This API is DEPRECATED.
-		// The mime type is now stored in the beagle:HitType property.
-		// To restrict on type, just do a normal property query.
-
-		public void AddHitType (string str)
+		public bool AllowsDomain (QueryDomain domain)
 		{
-			hitTypes.Add (str);
-
-			if (hit_type_part == null) {
-				hit_type_part = new QueryPart_Or ();
-				AddPart (hit_type_part);
-			}
-
-			// Add a part for this hit type.
-			QueryPart_Property part;
-			part = new QueryPart_Property ();
-			part.Type = PropertyType.Keyword;
-			part.Key = "beagle:HitType";
-			part.Value = str;
-			hit_type_part.Add (part);
+			return (domain_flags & domain) != 0;
 		}
 
-		public bool AllowsHitType (string str)
-		{
-			if (hitTypes.Count == 0)
-				return true;
-			foreach (string ht in hitTypes)
-				if (str == ht)
-					return true;
-			return false;
-		}
-
-		[XmlArrayItem (ElementName="HitType",
-			       Type=typeof(string))]
-		[XmlArray (ElementName="HitTypes")]
-		public ArrayList HitTypes {
-			get { return hitTypes; }
-		}
-
-		[XmlIgnore]
-		public bool HasHitTypes {
-			get { return hitTypes.Count > 0; }
-		}
-
-		///////////////////////////////////////////////////////////////
-
-		// This API is DEPRECATED.
-		// The source is now stored in the beagle:Source property.
-		// To restrict on source, just do a normal property query.
-
-		public void AddSource (string str)
-		{
-			searchSources.Add (str);
-
-			if (source_part == null) {
-				source_part = new QueryPart_Or ();
-				AddPart (source_part);
-			}
-
-			// Add a part for this source type.
-			QueryPart_Property part;
-			part = new QueryPart_Property ();
-			part.Type = PropertyType.Keyword;
-			part.Key = "beagle:Source";
-			part.Value = str;
-			source_part.Add (part);
-		}
-		
-
-		public bool AllowsSource (string str)
-		{
-			if (searchSources.Count == 0)
-				return true;
-			foreach (string ss in searchSources)
-				if (str == ss)
-					return true;
-			return false;
-		}
-
-		[XmlArrayItem (ElementName="Source",
-			       Type=typeof (string))]
-		[XmlArray (ElementName="Sources")]
-		public ArrayList Sources {
-			get { return searchSources; }
-		}
-
-		[XmlIgnore]
-		public bool HasSources {
-			get { return searchSources.Count > 0; }
-		}
-
-		///////////////////////////////////////////////////////////////
-
 		public QueryDomain QueryDomain {
-			get { return domainFlags; }
-			set { domainFlags = value; }
-		}
-
-		public void AddDomain (Beagle.QueryDomain d)
-		{
-			domainFlags |= d;
-		}
-
-		public void RemoveDomain (Beagle.QueryDomain d)
-		{
-			domainFlags &= ~d;
-		}
-
-		public bool AllowsDomain (Beagle.QueryDomain d)
-		{
-			return (domainFlags & d) != 0;
+			get { return domain_flags; }
+			set { domain_flags = value; }
 		}
 
 		///////////////////////////////////////////////////////////////
@@ -379,9 +231,7 @@ namespace Beagle {
 
 		[XmlIgnore]
 		public bool IsEmpty {
-			get { return parts.Count == 0
-				      && mimeTypes.Count == 0
-				      && searchSources.Count == 0; }
+			get { return parts.Count == 0; }
 		}
 
 		public override string ToString ()
