@@ -34,7 +34,6 @@ using System.Text.RegularExpressions;
 using System.Xml;
 using System.Xml.Schema;
 using System.Xml.Serialization;
-using Mono.Unix;
 
 namespace Beagle.Util {
 
@@ -280,14 +279,6 @@ namespace Beagle.Util {
 			get { return Get (Conf.Names.NetworkingConfig); }
 		}
 
-		private static string global_dir = Path.Combine (
-						Path.Combine (ExternalStringsHack.SysConfDir, "beagle"),
-						"config-files");
-
-		public static string GlobalDir {
-			get { return global_dir; }
-		}
-
 		// Utility method to check if global config files exist for the main config types
 		public static bool CheckGlobalConfig ()
 		{
@@ -296,7 +287,7 @@ namespace Beagle.Util {
 								Names.DaemonConfig,
 								Names.NetworkingConfig}) {
 				string filename = (name + ".xml");
-				string global_file = Path.Combine (global_dir, filename);
+				string global_file = Path.Combine (PathFinder.GlobalConfigDir, filename);
 				if (! File.Exists (global_file))
 					return false;
 			}
@@ -312,7 +303,7 @@ namespace Beagle.Util {
 		{
 			string filename = (name + ".xml");
 
-			string global_file = Path.Combine (global_dir, filename);
+			string global_file = Path.Combine (PathFinder.GlobalConfigDir, filename);
 			string local_file = Path.Combine (configs_dir, filename);
 
 			Config merge_from = LoadFrom (local_file);
@@ -379,7 +370,7 @@ namespace Beagle.Util {
 
 			using (StreamWriter writer = new StreamWriter (filename)) {
 				conf_ser.Serialize (writer, config);
-				Console.WriteLine ("Done writing to " + filename);
+				Log.Debug ("Done writing to " + filename);
 			}
 
 			watching_for_updates = watching_for_updates_current;
@@ -404,6 +395,72 @@ namespace Beagle.Util {
 			}
 		}
 
+		/* External clients can use the following two xml based methods to read/write xml */
+
+		// Use this method to write the config in its xml format.
+		public static void WriteSectionXml (Config config, TextWriter writer)
+		{
+			if (config == null)
+				return;
+
+			// serialize will not serialize global options,
+			// so temporarily make every option global
+			Dictionary<Option, bool> global_options = new Dictionary<Option, bool> ();
+			foreach (Option option in config.Options.Values) {
+				global_options [option] = option.Global;
+				option.Global = false;
+			}
+
+			conf_ser.Serialize (writer, config);
+
+			foreach (Option option in config.Options.Values)
+				option.Global = global_options [option];
+		}
+
+		// Use this method to send in the xml for a config, and the original config
+		// and the changes from the original to the xml will be added to the original config
+		// Returns false if the read xml does not correspond to the same config as that
+		// was passed, in which case please note that the passed config COULD BE IN A
+		// modified state and should be discarded!
+		public static bool ReadSectionXml (Config config, TextReader reader)
+		{
+			if (config == null)
+				throw new ArgumentException ("config", "config cannot be null");
+
+			Config new_config = (Config) conf_ser.Deserialize (reader);
+
+			foreach (Option new_option in new_config.Options.Values) {
+				Option option = config [new_option.Name] as Option;
+				if (option == null || (option.Type != new_option.Type))
+					return false;
+
+				switch (option.Type) {
+				case OptionType.Bool:
+					BoolOption option_bool = (BoolOption) option;
+					BoolOption new_option_bool = (BoolOption) new_option;
+					option_bool.Value = new_option_bool.Value;
+					break;
+
+				case OptionType.String:
+					StringOption option_str = (StringOption) option;
+					StringOption new_option_str = (StringOption) new_option;
+					option_str.Value = new_option_str.Value;
+					break;
+
+				case OptionType.List:
+					ListOption option_list = (ListOption) option;
+					ListOption new_option_list = (ListOption) new_option;
+					if (option_list.NumParams != new_option_list.NumParams)
+						return false;
+
+					option_list.Values = new_option_list.Values;
+					break;
+				}
+			}
+
+			return true;
+		}
+
 		private static void CheckOldConfig ()
 		{
 			// Load the local config files
@@ -421,19 +478,19 @@ namespace Beagle.Util {
 			Log.Info ("Old config files found. Moving them to the new format...");
 
 			// Load the global config files
-			Config global_fsq_config = LoadFrom (Path.Combine (global_dir, Names.FilesQueryableConfig + ".xml"));
+			Config global_fsq_config = LoadFrom (Path.Combine (PathFinder.GlobalConfigDir, Names.FilesQueryableConfig + ".xml"));
 			foreach (Option option in global_fsq_config.Options.Values)
 				option.Global = true;
 
-			Config global_networking_config = LoadFrom (Path.Combine (global_dir, Names.NetworkingConfig + ".xml"));
+			Config global_networking_config = LoadFrom (Path.Combine (PathFinder.GlobalConfigDir, Names.NetworkingConfig + ".xml"));
 			foreach (Option option in global_networking_config.Options.Values)
 				option.Global = true;
 
-			Config global_bs_config = LoadFrom (Path.Combine (global_dir, Names.BeagleSearchConfig + ".xml"));
+			Config global_bs_config = LoadFrom (Path.Combine (PathFinder.GlobalConfigDir, Names.BeagleSearchConfig + ".xml"));
 			foreach (Option option in global_bs_config.Options.Values)
 				option.Global = true;
 
-			Config global_daemon_config = LoadFrom (Path.Combine (global_dir, Names.DaemonConfig + ".xml"));
+			Config global_daemon_config = LoadFrom (Path.Combine (PathFinder.GlobalConfigDir, Names.DaemonConfig + ".xml"));
 			foreach (Option option in global_daemon_config.Options.Values)
 				option.Global = true;
 
@@ -915,10 +972,10 @@ namespace Beagle.Util {
 		[XmlIgnore]
 		public List<string[]> Values {
 			get {
-				if (Count == 0)
-					return null;
-
 				List<string[]> list = new List<string[]> (Count);
+				if (Count == 0)
+					return list;
+
 				int num_params = NumParams;
 
 				foreach (string value in Values_String) {
@@ -1331,7 +1388,7 @@ namespace Beagle.Util {
 		private bool password_required = true;
 
 		// The name and password for the local network service
-		private string service_name = String.Format ("{0} ({1})", UnixEnvironment.UserName, UnixEnvironment.MachineName);
+		private string service_name = String.Format ("{0} ({1})", Environment.UserName, System.Environment.MachineName);
 		private string service_password = String.Empty;
 
 		// This is a list of registered and paired nodes which
