@@ -64,6 +64,9 @@ namespace Beagle.Daemon
 
 		/////////////////////////////////////////////////////////
 
+		// 1. Different handling of --disable-directories
+		const int MINOR_VERSION = 1;
+
 		// Files and directories that are allowed to be in the target
 		// directory before we blow it away.  If we encounter any file
 		// or dir not in this list, we'll bail out.
@@ -216,6 +219,9 @@ namespace Beagle.Daemon
 					break;
 
 				default:
+					if (arg.StartsWith ("-") || arg.StartsWith ("--"))
+						PrintUsage ();
+
 					string path = Path.IsPathRooted (arg) ? arg : Path.GetFullPath (arg);
 					if (path != "/" && path.EndsWith ("/"))
 						path = path.TrimEnd ('/');
@@ -304,12 +310,12 @@ namespace Beagle.Daemon
 				arg_source = dir.Name;
 			}
 
-			if (SystemInformation.UsingBattery && arg_disable_on_battery) {
+			if (Battery.UsingBattery && arg_disable_on_battery) {
 				Log.Always ("Indexer is disabled when on battery power (--disable-on-battery)");
 				Environment.Exit (0);
 			}
 
-			string global_files_config = Path.Combine (Conf.GlobalDir, Conf.Names.FilesQueryableConfig + ".xml");
+			string global_files_config = Path.Combine (PathFinder.GlobalConfigDir, Conf.Names.FilesQueryableConfig + ".xml");
 			if (! File.Exists (global_files_config)) {
 				Log.Error ("Global configuration file not found {0}", global_files_config);
 				Environment.Exit (0);
@@ -331,11 +337,6 @@ namespace Beagle.Daemon
 					denied_regex = StringFu.GetPatternRegex (denied_patterns);
 			}
 
-			if (arg_disable_directories && arg_delete) {
-				Log.Warn ("--enable-deletion is ignored as --disable-directories is used");
-				arg_delete = false;
-			}
-
 			Log.Always ("Starting beagle-build-index (pid {0}) at {1}", Process.GetCurrentProcess ().Id, DateTime.Now);
 
 			// Set system priorities so we don't slow down the system
@@ -343,7 +344,7 @@ namespace Beagle.Daemon
 			SystemPriorities.SetSchedulerPolicyBatch ();
 			SystemPriorities.Renice (19);
 			
-			driver = new LuceneIndexingDriver (arg_output, false);
+			driver = new LuceneIndexingDriver (arg_output, MINOR_VERSION, false);
 			driver.TextCache = (arg_cache_text) ? new TextCache (arg_output) : null;
 			if (driver.TextCache != null)
 				driver.TextCache.WorldReadable = true;
@@ -429,8 +430,7 @@ namespace Beagle.Daemon
 			while (pending_directories.Count > 0) {
 				DirectoryInfo dir = (DirectoryInfo) pending_directories.Dequeue ();
 
-				if (! arg_disable_directories)
-					AddToRequest (DirectoryToIndexable (dir, modified_directories));
+				AddToRequest (DirectoryToIndexable (dir, modified_directories));
 
 				try {
 					if (arg_recursive)
@@ -470,7 +470,7 @@ namespace Beagle.Daemon
 				ICollection all_dirent = GetAllItemsInDirectory (subdir);
 				foreach (Dirent info in all_dirent) {
 					// check if the item exists
-					if (File.Exists (info.FullName) || 
+					if ((! info.IsDirectory && File.Exists (info.FullName)) || 
 					    (info.IsDirectory && Directory.Exists (info.FullName)))
 						continue;
 
@@ -537,7 +537,6 @@ namespace Beagle.Daemon
 					Logger.Log.Debug ("Flushing driver, {0} items in queue", pending_request.Count);
 
 				reschedule = FlushIndexer (driver);
-				Console.WriteLine (reschedule);
 
 				// Super Lame Hack: gtk-sharp up to 2.10 requires a main loop
 				// to dispose of any managed wrappers around GObjects.  Since
@@ -643,11 +642,12 @@ namespace Beagle.Daemon
 			Indexable indexable = new Indexable (uri);
 			indexable.Timestamp = file.LastWriteTimeUtc;
 			indexable.Crawled = true;
+			indexable.AddProperty (Property.NewUnsearched ("fixme:filesize", file.Length));
 			FSQ.AddStandardPropertiesToIndexable (indexable, file.Name, Guid.Empty, false);
 
 			// Store directory name in the index
 			string dirname = file.DirectoryName;
-			indexable.AddProperty (Property.NewUnsearched (ParentDirUriPropKey, UriFu.PathToFileUri (dirname)));
+			indexable.AddProperty (Property.NewUnsearched (Property.ParentDirUriPropKey, UriFu.PathToFileUri (dirname)));
 
 			return indexable;
 		}
@@ -661,11 +661,17 @@ namespace Beagle.Daemon
 			// And if the mtime of the directory is same as that in the attributes store
 			FileAttributes attr = fa_store.Read (dir.FullName);
 
-			// If the directory exists in the fa store, then it is already indexed
+			// If the directory exists in the fa store, then it is already indexed.
 			if (attr != null) {
-				if (arg_delete && ! FileAttributesStore.IsUpToDate (dir.FullName, attr))
-					modified_directories.Enqueue (dir);
-				return null;
+				// If we don't care about deleted content then we are fine.
+				// If the attributes are up-to-date, then we are fine too.
+				if (! arg_delete || FileAttributesStore.IsUpToDate (dir.FullName, attr))
+					return null;
+
+				// But the last write time needs to be uptodate to support enable-deletion,
+				// so we actually index the directories, even if --disable-directories
+				// is set.
+				modified_directories.Enqueue (dir);
 			}
 
 			// Create the indexable and add the standard properties we
@@ -675,13 +681,18 @@ namespace Beagle.Daemon
 			indexable.MimeType = "inode/directory";
 			indexable.NoContent = true;
 			indexable.Timestamp = dir.LastWriteTimeUtc;
-			FSQ.AddStandardPropertiesToIndexable (indexable, dir.Name, Guid.Empty, false);
+
+			// Store the directory information in the index anyway, but if --disable-directories
+			// was passed, then do not store the names and other standard properties
+			// used during searching
+			if (! arg_disable_directories)
+				FSQ.AddStandardPropertiesToIndexable (indexable, dir.Name, Guid.Empty, false);
 
 			// Add directory name property
 			string dirname = dir.Parent.FullName;
-			indexable.AddProperty (Property.NewUnsearched (ParentDirUriPropKey, UriFu.PathToFileUri (dirname)));
+			indexable.AddProperty (Property.NewUnsearched (Property.ParentDirUriPropKey, UriFu.PathToFileUri (dirname)));
 
-			indexable.AddProperty (Property.NewBool (IsDirectoryPropKey, true));
+			indexable.AddProperty (Property.NewBool (Property.IsDirectoryPropKey, true));
 
 			return indexable;
 		}
@@ -724,18 +735,15 @@ namespace Beagle.Daemon
 			}
 		}
 
-		private const string ParentDirUriPropKey = "beagle:ParentDirUri";
-		private const string IsDirectoryPropKey = "beagle:IsDirectory";
-
 		// Returns a list of all files and directories in dir
 		static ICollection GetAllItemsInDirectory (DirectoryInfo dir)
 		{
 			// form the query
 			string parent_uri_str = UriFu.PathToFileUri (dir.FullName).ToString ();
+
 			// Instead of taking the painfull way of using BeagleAnalyzer, lets just add the prefix manually
-			//parent_uri_str = "_:" + parent_uri_str;
 			// LuceneCommon thinks exposing secret property type encoding is bad, I think so too... except for now
-			string key = "prop:k:" + ParentDirUriPropKey;
+			string key = "prop:k:" + Property.ParentDirUriPropKey;
 			//Logger.Log.Debug ("Querying for {0}={1}", parent_uri_str, key);
 			LNS.Query query = new LNS.TermQuery (new Term (key, parent_uri_str));
 
@@ -786,12 +794,13 @@ namespace Beagle.Daemon
 
 			path = doc.Get ("Uri");
 
-			string prop_key = "prop:k:" + IsDirectoryPropKey;
+			string prop_key = "prop:k:" + Property.IsDirectoryPropKey;
 			foreach (Field f in doc.Fields ()) {
 				if (f.Name () != prop_key)
 					continue;
 
-				is_dir = (f.StringValue ().Substring (2) == "true");
+				// Format of fields: from LuceneCommon.cs:AddPropertyToDocument
+				is_dir = (f.StringValue ().Substring (3) == "true");
 				break;
 			}
 
@@ -877,17 +886,14 @@ namespace Beagle.Daemon
 				"  --recursive\t\t\tCrawl source path recursivly.\n" + 
 				"  --enable-deletion\t\tRemove deleted files and directories from index.\n" +
 				"                   \t\tIndex should be created and always updated with this option.\n" +
-				"                   \t\tOption only works if --disable-directories is NOT specified.\n" +
 				"  --enable-text-cache\t\tBuild text-cache of documents used for snippets.\n" +
 				"  --disable-directories\t\tDon't add directories to the index.\n" +
 				"  --disable-filtering\t\tDisable all filtering of files. Only index attributes.\n" + 
 				"  --allow-pattern [pattern]\tOnly allow files that match the pattern to be indexed.\n" + 
 				"  --deny-pattern [pattern]\tKeep any files that match the pattern from being indexed.\n" + 
 				"  --disable-restart\t\tDon't restart when memory usage gets above a certain threshold.\n" +
-				"  --disable-on-battery\t\tDisable indexer while on battery power.\n" +
-				"  --debug\t\t\tEcho verbose debugging information.\n\n";
+				"  --disable-on-battery\t\tDisable indexer while on battery power.\n";
 
-			
 			Console.WriteLine (usage);
 			Environment.Exit (0);
 		}
