@@ -24,10 +24,11 @@
 // DEALINGS IN THE SOFTWARE.
 //
 
-
 using System;
 using System.Collections;
 
+using Beagle.Util;
+
 namespace Beagle.Daemon {
 
 	public interface IQueryable {
@@ -40,14 +41,17 @@ namespace Beagle.Daemon {
 			      IQueryResult result,
 			      IQueryableChangeData data);
 
-		string GetSnippet (string[] query_terms, Hit hit);
+		ISnippetReader GetSnippet (string[] query_terms, Hit hit, bool full_text);
 
-		// Returns the total number of items in this Queryable's index,
-		// or a value < 0 if that number is unknown or undefined.
-		int GetItemCount ();
+		QueryableStatus GetQueryableStatus ();
 	}
 
 	public interface IQueryableChangeData { 
 	
 	}
+
+	[AttributeUsage (AttributeTargets.Assembly)]
+	public class IQueryableTypesAttribute : TypeCacheAttribute {
+		public IQueryableTypesAttribute (params Type[] queryable_types) : base (queryable_types) { }
+	}
 }
